summaryrefslogtreecommitdiffstats
path: root/Source/cmGlobalVisualStudio6Generator.cxx
diff options
context:
space:
mode:
authorAndy Cedilnik <andy.cedilnik@kitware.com>2003-08-04 02:34:37 (GMT)
committerAndy Cedilnik <andy.cedilnik@kitware.com>2003-08-04 02:34:37 (GMT)
commit0b150f69c2a724b8ec097ca1657c089a6e2861e8 (patch)
treeabe8d82ca0a9127a3e01e11afa8b2124e3950634 /Source/cmGlobalVisualStudio6Generator.cxx
parent32c2ed2ef37990060238d2e136b255d7074f6ae4 (diff)
downloadCMake-0b150f69c2a724b8ec097ca1657c089a6e2861e8.zip
CMake-0b150f69c2a724b8ec097ca1657c089a6e2861e8.tar.gz
CMake-0b150f69c2a724b8ec097ca1657c089a6e2861e8.tar.bz2
ENH: Use the new RunCommand
Diffstat (limited to 'Source/cmGlobalVisualStudio6Generator.cxx')
-rw-r--r--Source/cmGlobalVisualStudio6Generator.cxx6
1 files changed, 4 insertions, 2 deletions
diff --git a/Source/cmGlobalVisualStudio6Generator.cxx b/Source/cmGlobalVisualStudio6Generator.cxx
index 233a9e2..b04713a 100644
--- a/Source/cmGlobalVisualStudio6Generator.cxx
+++ b/Source/cmGlobalVisualStudio6Generator.cxx
@@ -96,7 +96,7 @@ int cmGlobalVisualStudio6Generator::TryCompile(const char *,
cmSystemTools::ChangeDirectory(bindir);
// if there are spaces in the makeCommand, assume a full path
// and convert it to a path with no spaces in it as the
// RunCommand does not like spaces
#if defined(_WIN32) && !defined(__CYGWIN__)
if(makeCommand.find(' ') != std::string::npos)
{
@@ -116,7 +116,9 @@ int cmGlobalVisualStudio6Generator::TryCompile(const char *,
}
makeCommand += " - Debug\"";
int retVal;
- if (!cmSystemTools::RunCommand(makeCommand.c_str(), *output, retVal, 0, false))
+ int timeout = cmGlobalGenerator::s_TryCompileTimeout;
+ if (!cmSystemTools::RunSingleCommand(makeCommand.c_str(), output,
+ &retVal, 0, false, timeout))
{
std::string e = "Error executing make program \"";
e += originalCommand;
@@ -96,7 +96,7 @@ int cmGlobalVisualStudio6Generator::TryCompile(const char *,
// if there are spaces in the makeCommand, assume a full path
// and convert it to a path with no spaces in it as the
- // RunCommand does not like spaces
+ // RunSingleCommand does not like spaces
#if defined(_WIN32) && !defined(__CYGWIN__)
if(makeCommand.find(' ') != std::string::npos)